

/* new button: EtcA1 */
#define EtcA1_offo_width 27
#define EtcA1_offo_height 14
static unsigned char EtcA1_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x3a, 0x18, 0x22, 0x02, 0x46, 0x24, 0x22, 0x02,
  0x42, 0x42, 0x54, 0x01, 0x42, 0x7e, 0x54, 0x01, 0x42, 0x02, 0x54, 0x01,
  0x42, 0x44, 0x88, 0x00, 0x42, 0x38, 0x88, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA1_offo_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x7f, 0x3c, 0x77, 0x07, 0xff, 0x7e, 0x77, 0x07, 0xff, 0xff, 0xff, 0x07,
  0xef, 0xff, 0xff, 0x07, 0xe7, 0xff, 0xfe, 0x03, 0xe7, 0xff, 0xfe, 0x03,
  0xe7, 0xff, 0xfe, 0x03, 0xe7, 0xfe, 0xdc, 0x01, 0xe7, 0x7c, 0xdc, 0x01,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA1_offo_breaks[] = { 8, 16, 27 };
static ButtonLabel EtcA1_offo = {
  (unsigned char *)EtcA1_offo_label, (unsigned char *)EtcA1_offo_mask,
  EtcA1_offo_width, EtcA1_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 3, 0, EtcA1_offo_breaks };
#define EtcA1_offi_width 28
#define EtcA1_offi_height 14
static unsigned char EtcA1_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x3f, 0x3e, 0x23, 0x06, 0x63, 0x63, 0x23, 0x06,
  0x63, 0x63, 0x76, 0x03, 0x63, 0x7f, 0x76, 0x03, 0x63, 0x03, 0xde, 0x03,
  0x63, 0x63, 0x8c, 0x01, 0x63, 0x3e, 0x8c, 0x01, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA1_offi_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x7f, 0xff, 0x77, 0x0f, 0xff, 0xff, 0x77, 0x0f, 0xff, 0xff, 0xff, 0x0f,
  0xf7, 0xff, 0xff, 0x0f, 0xf7, 0xff, 0xff, 0x07, 0xf7, 0xff, 0xff, 0x07,
  0xf7, 0xff, 0xff, 0x07, 0xf7, 0xff, 0xde, 0x03, 0xf7, 0x7f, 0xde, 0x03,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA1_offi_breaks[] = { 8, 16, 28 };
static ButtonLabel EtcA1_offi = {
  (unsigned char *)EtcA1_offi_label, (unsigned char *)EtcA1_offi_mask,
  EtcA1_offi_width, EtcA1_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 3, 0, EtcA1_offi_breaks };
static ButtonLook EtcA1_look = {
  &EtcA1_offo, NULL, &EtcA1_offo, NULL,
  &EtcA1_offi, NULL, &EtcA1_offi, NULL };
static ButtonFeel EtcA1_feel = {
  "EtcA1", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 3, 144, 0, 0 } };
/* track button: EtcA2 */
#define EtcA2_offo_width 35
#define EtcA2_offo_height 14
static unsigned char EtcA2_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x04, 0x00,
  0x00, 0x20, 0x00, 0x04, 0x00, 0x00, 0x20, 0x00, 0x9e, 0xc6, 0x81, 0x23,
  0x02, 0x84, 0x21, 0x42, 0x24, 0x01, 0x84, 0x00, 0x23, 0xe0, 0x00, 0x84,
  0xc0, 0x22, 0xa0, 0x00, 0x84, 0x20, 0x22, 0x20, 0x01, 0x84, 0x20, 0x42,
  0x24, 0x02, 0x98, 0xc0, 0x85, 0x23, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA2_offo_mask[] = {
  0x00, 0x00, 0x00, 0x70, 0x00, 0x0e, 0x00, 0x00, 0x70, 0x00, 0x0e, 0x00,
  0x00, 0x70, 0x00, 0xff, 0xef, 0xc3, 0x77, 0x07, 0xff, 0xff, 0xe7, 0xff,
  0x07, 0xff, 0xff, 0xf7, 0xff, 0x07, 0xce, 0xf3, 0xf7, 0xfe, 0x03, 0xce,
  0xf1, 0x77, 0xf0, 0x03, 0xce, 0xf1, 0xf7, 0xfe, 0x07, 0xfe, 0xf1, 0xff,
  0xff, 0x07, 0xfe, 0xf1, 0xef, 0x7f, 0x07, 0xfc, 0xe1, 0xcf, 0x77, 0x06,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA2_offo_breaks[] = { 6, 12, 20, 28, 35 };
static ButtonLabel EtcA2_offo = {
  (unsigned char *)EtcA2_offo_label, (unsigned char *)EtcA2_offo_mask,
  EtcA2_offo_width, EtcA2_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, EtcA2_offo_breaks };
#define EtcA2_offi_width 36
#define EtcA2_offi_height 14
static unsigned char EtcA2_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x06, 0x00,
  0x00, 0x30, 0x00, 0x06, 0x00, 0x00, 0x30, 0x00, 0xdf, 0xe7, 0xe1, 0x33,
  0x03, 0xc6, 0x36, 0x33, 0xb6, 0x01, 0xc6, 0x00, 0x33, 0xf0, 0x00, 0xc6,
  0xe0, 0x33, 0xf0, 0x00, 0xc6, 0x30, 0x33, 0xb6, 0x01, 0xc6, 0x30, 0x33,
  0x36, 0x03, 0xdc, 0xe0, 0xe6, 0x33, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA2_offi_mask[] = {
  0x00, 0x00, 0x00, 0x78, 0x00, 0x0f, 0x00, 0x00, 0x78, 0x00, 0x0f, 0x00,
  0x00, 0x78, 0x00, 0xff, 0xff, 0xf3, 0xff, 0x07, 0xff, 0xff, 0xff, 0xff,
  0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xef, 0xff, 0x7f, 0xff, 0x03, 0xef,
  0xf9, 0x7f, 0xff, 0x03, 0xef, 0xf9, 0x7f, 0xff, 0x07, 0xff, 0xf9, 0xff,
  0xff, 0x0f, 0xff, 0xf9, 0xff, 0xff, 0x0f, 0xfe, 0xf1, 0xff, 0x7f, 0x0f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA2_offi_breaks[] = { 6, 12, 20, 28, 36 };
static ButtonLabel EtcA2_offi = {
  (unsigned char *)EtcA2_offi_label, (unsigned char *)EtcA2_offi_mask,
  EtcA2_offi_width, EtcA2_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, EtcA2_offi_breaks };
static ButtonLook EtcA2_look = {
  &EtcA2_offo, NULL, &EtcA2_offo, NULL,
  &EtcA2_offi, NULL, &EtcA2_offi, NULL };
static ButtonFeel EtcA2_feel = {
  "EtcA2", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 3, 64, 0, 0 } };
/* coord button: EtcA3 */
#define EtcA3_offo_width 40
#define EtcA3_offo_height 14
static unsigned char EtcA3_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
  0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x40, 0x38, 0x38, 0x70, 0x68,
  0x58, 0x44, 0x44, 0x88, 0x18, 0x64, 0x02, 0x82, 0x04, 0x09, 0x42, 0x02,
  0x82, 0x04, 0x09, 0x42, 0x02, 0x82, 0x04, 0x09, 0x42, 0x44, 0x44, 0x88,
  0x08, 0x64, 0x38, 0x38, 0x70, 0x08, 0x58, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA3_offo_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0xe0, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x00, 0x00,
  0x00, 0x00, 0xe0, 0x7c, 0x7c, 0xf8, 0xfc, 0xfc, 0xfe, 0xfe, 0xfc, 0xfd,
  0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xef, 0xdf, 0x3f, 0xff, 0x07,
  0xc7, 0x8f, 0x1f, 0xe7, 0xef, 0xef, 0xdf, 0x1f, 0xff, 0xff, 0xff, 0xff,
  0x1f, 0xff, 0xfe, 0xfe, 0xfc, 0x1d, 0xfe, 0x7c, 0x7c, 0xf8, 0x1c, 0xfc,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA3_offo_breaks[] = { 8, 17, 26, 32, 40 };
static ButtonLabel EtcA3_offo = {
  (unsigned char *)EtcA3_offo_label, (unsigned char *)EtcA3_offo_mask,
  EtcA3_offo_width, EtcA3_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, EtcA3_offo_breaks };
#define EtcA3_offi_width 38
#define EtcA3_offi_height 14
static unsigned char EtcA3_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00,
  0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x18, 0x3e, 0x3e, 0x3e, 0x9f,
  0x1f, 0x63, 0x63, 0x63, 0xdb, 0x18, 0x03, 0x63, 0x63, 0xc3, 0x18, 0x03,
  0x63, 0x63, 0xc3, 0x18, 0x63, 0x63, 0x63, 0xc3, 0x18, 0x63, 0x63, 0x63,
  0xc3, 0x18, 0x3e, 0x3e, 0x3e, 0x83, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA3_offi_mask[] = {
  0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00,
  0x00, 0x00, 0x3c, 0x7f, 0x7f, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff,
  0x3f, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xf7, 0xf7, 0xf7, 0xff, 0x3d, 0xf7,
  0xf7, 0xf7, 0xe7, 0x3d, 0xf7, 0xf7, 0xf7, 0xe7, 0x3d, 0xff, 0xff, 0xff,
  0xe7, 0x3f, 0xff, 0xff, 0xff, 0xe7, 0x3f, 0x7f, 0x7f, 0xff, 0xc7, 0x3f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA3_offi_breaks[] = { 8, 16, 24, 30, 38 };
static ButtonLabel EtcA3_offi = {
  (unsigned char *)EtcA3_offi_label, (unsigned char *)EtcA3_offi_mask,
  EtcA3_offi_width, EtcA3_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, EtcA3_offi_breaks };
static ButtonLook EtcA3_look = {
  &EtcA3_offo, NULL, &EtcA3_offo, NULL,
  &EtcA3_offi, NULL, &EtcA3_offi, NULL };
static ButtonFeel EtcA3_feel = {
  "EtcA3", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 3, 96, 0, 0 } };
/* verb button: EtcA4 */
#define EtcA4_offo_width 31
#define EtcA4_offo_height 14
static unsigned char EtcA4_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x01,
  0x00, 0x00, 0x00, 0x01, 0x82, 0x30, 0x34, 0x0d, 0x82, 0x48, 0x0c, 0x13,
  0x44, 0x84, 0x04, 0x21, 0x44, 0xfc, 0x04, 0x21, 0x28, 0x04, 0x04, 0x21,
  0x28, 0x88, 0x04, 0x13, 0x10, 0x70, 0x04, 0x0d, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA4_offo_mask[] = {
  0x00, 0x00, 0x80, 0x03, 0x00, 0x00, 0x80, 0x03, 0x00, 0x00, 0x80, 0x03,
  0xc7, 0x79, 0xfe, 0x1f, 0xc7, 0xfd, 0xfe, 0x3f, 0xef, 0xff, 0xff, 0x7f,
  0xef, 0xff, 0x9f, 0x7f, 0xfe, 0xfe, 0x8f, 0x73, 0xfe, 0xfe, 0x8f, 0x7f,
  0x7c, 0xfe, 0x8f, 0x7f, 0x7c, 0xfc, 0x8f, 0x3f, 0x38, 0xf8, 0x8e, 0x1f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA4_offo_breaks[] = { 9, 17, 23, 31 };
static ButtonLabel EtcA4_offo = {
  (unsigned char *)EtcA4_offo_label, (unsigned char *)EtcA4_offo_mask,
  EtcA4_offo_width, EtcA4_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 4, 0, EtcA4_offo_breaks };
#define EtcA4_offi_width 31
#define EtcA4_offi_height 14
static unsigned char EtcA4_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x00, 0x00, 0x80, 0x01,
  0x00, 0x00, 0x80, 0x01, 0xc3, 0x7c, 0xbe, 0x1f, 0xc3, 0xc6, 0xb6, 0x31,
  0x66, 0xc6, 0x86, 0x31, 0x66, 0xfe, 0x86, 0x31, 0x24, 0x06, 0x86, 0x31,
  0x3c, 0xc6, 0x86, 0x31, 0x18, 0x7c, 0x86, 0x1f, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA4_offi_mask[] = {
  0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0xc0, 0x03,
  0xe7, 0xff, 0xff, 0x3f, 0xe7, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f,
  0xff, 0xff, 0xff, 0x7b, 0xff, 0xff, 0xcf, 0x7b, 0xff, 0xff, 0xcf, 0x7b,
  0x7e, 0xff, 0xcf, 0x7f, 0x7e, 0xff, 0xcf, 0x7f, 0x3c, 0xfe, 0xcf, 0x3f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA4_offi_breaks[] = { 9, 17, 23, 31 };
static ButtonLabel EtcA4_offi = {
  (unsigned char *)EtcA4_offi_label, (unsigned char *)EtcA4_offi_mask,
  EtcA4_offi_width, EtcA4_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 4, 0, EtcA4_offi_breaks };
static ButtonLook EtcA4_look = {
  &EtcA4_offo, NULL, &EtcA4_offo, NULL,
  &EtcA4_offi, NULL, &EtcA4_offi, NULL };
static ButtonFeel EtcA4_feel = {
  "EtcA4", 2,
  { BTNToggle, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 3, 16, 0, 0 } };
/* print button: EtcA5 */
#define EtcA5_offo_width 31
#define EtcA5_offo_height 14
static unsigned char EtcA5_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x80, 0x00, 0x08,
  0x00, 0x00, 0x00, 0x08, 0x1a, 0x9a, 0x74, 0x3c, 0x26, 0x86, 0x8c, 0x08,
  0x42, 0x82, 0x84, 0x08, 0x42, 0x82, 0x84, 0x08, 0x42, 0x82, 0x84, 0x08,
  0x26, 0x82, 0x84, 0x08, 0x1a, 0x82, 0x84, 0x30, 0x02, 0x00, 0x00, 0x00,
  0x02, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00 };
static unsigned char EtcA5_offo_mask[] = {
  0x00, 0xc0, 0x01, 0x00, 0x00, 0xc0, 0x01, 0x1c, 0x00, 0xc0, 0x01, 0x1c,
  0x3f, 0xff, 0xff, 0x7e, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f,
  0xff, 0xcf, 0xdf, 0x1d, 0xe7, 0xc7, 0xcf, 0x1d, 0xff, 0xc7, 0xcf, 0x1d,
  0xff, 0xc7, 0xcf, 0x7d, 0x7f, 0xc7, 0xcf, 0x7d, 0x3f, 0xc7, 0xcf, 0x79,
  0x07, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00 };
static int EtcA5_offo_breaks[] = { 8, 14, 17, 25, 31 };
static ButtonLabel EtcA5_offo = {
  (unsigned char *)EtcA5_offo_label, (unsigned char *)EtcA5_offo_mask,
  EtcA5_offo_width, EtcA5_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 5, 0, EtcA5_offo_breaks };
#define EtcA5_offi_width 31
#define EtcA5_offi_height 14
static unsigned char EtcA5_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x0c,
  0x00, 0x00, 0x00, 0x0c, 0x3f, 0xdf, 0x7e, 0x3e, 0x63, 0xdb, 0xc6, 0x0c,
  0x63, 0xc3, 0xc6, 0x0c, 0x63, 0xc3, 0xc6, 0x0c, 0x63, 0xc3, 0xc6, 0x0c,
  0x63, 0xc3, 0xc6, 0x0c, 0x3f, 0xc3, 0xc6, 0x38, 0x03, 0x00, 0x00, 0x00,
  0x03, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00 };
static unsigned char EtcA5_offi_mask[] = {
  0x00, 0xe0, 0x01, 0x00, 0x00, 0xe0, 0x01, 0x1e, 0x00, 0xe0, 0x01, 0x1e,
  0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f,
  0xf7, 0xff, 0xef, 0x1f, 0xf7, 0xe7, 0xef, 0x1f, 0xf7, 0xe7, 0xef, 0x1f,
  0xff, 0xe7, 0xef, 0x7f, 0xff, 0xe7, 0xef, 0x7f, 0xff, 0xe7, 0xef, 0x7d,
  0x07, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00 };
static int EtcA5_offi_breaks[] = { 8, 14, 17, 25, 31 };
static ButtonLabel EtcA5_offi = {
  (unsigned char *)EtcA5_offi_label, (unsigned char *)EtcA5_offi_mask,
  EtcA5_offi_width, EtcA5_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 5, 0, EtcA5_offi_breaks };
static ButtonLook EtcA5_look = {
  &EtcA5_offo, NULL, &EtcA5_offo, NULL,
  &EtcA5_offi, NULL, &EtcA5_offi, NULL };
static ButtonFeel EtcA5_feel = {
  "EtcA5", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 3, 128, 64, 0 } };
/* raise button: EtcA6 */
#define EtcA6_offo_width 33
#define EtcA6_offo_height 14
static unsigned char EtcA6_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x80,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1a, 0x87, 0x78, 0x30,
  0x00, 0x86, 0x88, 0x84, 0x48, 0x00, 0x02, 0x8c, 0x04, 0x84, 0x00, 0x02,
  0x8b, 0x78, 0xfc, 0x00, 0x82, 0x88, 0x80, 0x04, 0x00, 0x82, 0x88, 0x84,
  0x88, 0x00, 0x02, 0x97, 0x78, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA6_offo_mask[] = {
  0x00, 0xc0, 0x01, 0x00, 0x00, 0x00, 0xc0, 0x01, 0x00, 0x00, 0x00, 0xc0,
  0x01, 0x00, 0x00, 0xbf, 0xcf, 0xfd, 0x78, 0x00, 0xff, 0xdf, 0xff, 0xfd,
  0x00, 0xff, 0xdf, 0xff, 0xff, 0x01, 0xcf, 0xdf, 0xff, 0xff, 0x01, 0xc7,
  0xdf, 0xff, 0xff, 0x01, 0xc7, 0xdf, 0xff, 0xff, 0x01, 0xc7, 0xff, 0xff,
  0xff, 0x01, 0xc7, 0xff, 0xff, 0xfd, 0x01, 0x87, 0xff, 0xfd, 0xf8, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA6_offo_breaks[] = { 6, 14, 17, 25, 33 };
static ButtonLabel EtcA6_offo = {
  (unsigned char *)EtcA6_offo_label, (unsigned char *)EtcA6_offo_mask,
  EtcA6_offo_width, EtcA6_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 5, 0, EtcA6_offo_breaks };
#define EtcA6_offi_width 32
#define EtcA6_offi_height 14
static unsigned char EtcA6_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x9f, 0xc7, 0x3c, 0x3e, 0xdb, 0xcc, 0x66, 0x63,
  0x03, 0xcc, 0x0e, 0x63, 0x83, 0xcf, 0x3c, 0x7f, 0xc3, 0xcc, 0x70, 0x03,
  0xc3, 0xcc, 0x66, 0x63, 0x83, 0xdb, 0x3c, 0x3e, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static unsigned char EtcA6_offi_mask[] = {
  0x00, 0xe0, 0x01, 0x00, 0x00, 0xe0, 0x01, 0x00, 0x00, 0xe0, 0x01, 0x00,
  0xff, 0xef, 0x7f, 0x7f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
  0xff, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff,
  0xe7, 0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xff, 0xc7, 0xff, 0x7f, 0x7f,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
static int EtcA6_offi_breaks[] = { 6, 14, 17, 24, 32 };
static ButtonLabel EtcA6_offi = {
  (unsigned char *)EtcA6_offi_label, (unsigned char *)EtcA6_offi_mask,
  EtcA6_offi_width, EtcA6_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 5, 0, EtcA6_offi_breaks };
static ButtonLook EtcA6_look = {
  &EtcA6_offo, NULL, &EtcA6_offo, NULL,
  &EtcA6_offi, NULL, &EtcA6_offi, NULL };
static ButtonFeel EtcA6_feel = {
  "EtcA6", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 3, 32, 0, 0 } };
/* QUIT button: EtcA7 */
#define EtcA7_offo_width 36
#define EtcA7_offo_height 12
static unsigned char EtcA7_offo_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x20, 0x90, 0xfc, 0x07, 0x0c, 0x23,
  0x90, 0x40, 0x00, 0x04, 0x22, 0x90, 0x40, 0x00, 0x02, 0x24, 0x90, 0x40,
  0x00, 0x02, 0x24, 0x90, 0x40, 0x00, 0x02, 0x24, 0x90, 0x40, 0x00, 0x02,
  0x24, 0x90, 0x40, 0x00, 0x44, 0x22, 0x90, 0x40, 0x00, 0x8c, 0x43, 0x88,
  0x40, 0x00, 0xf0, 0x81, 0x87, 0x40, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00 };
static unsigned char EtcA7_offo_mask[] = {
  0xf8, 0x71, 0xf8, 0xff, 0x0f, 0xfe, 0x77, 0xf8, 0xff, 0x0f, 0xfe, 0x77,
  0xf8, 0xff, 0x0f, 0x9f, 0x7f, 0xf8, 0xe1, 0x00, 0x0f, 0x7f, 0xf8, 0xe1,
  0x00, 0x07, 0x7e, 0xf8, 0xe1, 0x00, 0x07, 0x7e, 0xf8, 0xe1, 0x00, 0xef,
  0x7f, 0xf8, 0xe1, 0x00, 0xff, 0xff, 0xfc, 0xe1, 0x00, 0xfe, 0xf7, 0xff,
  0xe1, 0x00, 0xfe, 0xe7, 0xdf, 0xe1, 0x00, 0xf8, 0xcf, 0xcf, 0xe1, 0x00 };
static int EtcA7_offo_breaks[] = { 12, 22, 25, 36 };
static ButtonLabel EtcA7_offo = {
  (unsigned char *)EtcA7_offo_label, (unsigned char *)EtcA7_offo_mask,
  EtcA7_offo_width, EtcA7_offo_height,
  0.5, 0.5, 0, 0,			/* placement */
  5, 4, 0, EtcA7_offo_breaks };
#define EtcA7_offi_width 31
#define EtcA7_offi_height 12
static unsigned char EtcA7_offi_label[] = {
  0x00, 0x00, 0x00, 0x00, 0x7c, 0x0c, 0xdb, 0x3f, 0xc6, 0x0c, 0x1b, 0x06,
  0x83, 0x0d, 0x1b, 0x06, 0x83, 0x0d, 0x1b, 0x06, 0x83, 0x0d, 0x1b, 0x06,
  0x83, 0x0d, 0x1b, 0x06, 0x83, 0x0d, 0x1b, 0x06, 0xb3, 0x0d, 0x1b, 0x06,
  0xe6, 0x98, 0x19, 0x06, 0xfc, 0xf0, 0x18, 0x06, 0x80, 0x01, 0x00, 0x00 };
static unsigned char EtcA7_offi_mask[] = {
  0xfe, 0x9e, 0xff, 0x7f, 0xff, 0x9f, 0xff, 0x7f, 0xff, 0x9f, 0xff, 0x7f,
  0xef, 0x9f, 0x3f, 0x0f, 0xc7, 0x9f, 0x3f, 0x0f, 0xc7, 0x9f, 0x3f, 0x0f,
  0xc7, 0x9f, 0x3f, 0x0f, 0xff, 0x9f, 0x3f, 0x0f, 0xff, 0xff, 0x3f, 0x0f,
  0xff, 0xff, 0x3f, 0x0f, 0xff, 0xff, 0x3f, 0x0f, 0xfe, 0xfb, 0x3d, 0x0f };
static int EtcA7_offi_breaks[] = { 10, 19, 22, 31 };
static ButtonLabel EtcA7_offi = {
  (unsigned char *)EtcA7_offi_label, (unsigned char *)EtcA7_offi_mask,
  EtcA7_offi_width, EtcA7_offi_height,
  0.5, 0.5, 0, 0,			/* placement */
  4, 4, 0, EtcA7_offi_breaks };
static ButtonLook EtcA7_look = {
  &EtcA7_offo, NULL, &EtcA7_offo, NULL,
  &EtcA7_offi, NULL, &EtcA7_offi, NULL };
static ButtonFeel EtcA7_feel = {
  "EtcA7", 2,
  { BTNOneShot, BTNCoWhile },
  { 0x0004, 0x0004 },
  { 0x0000, 0x0004 },
  { 3, 256, 0, 0 } };
static ButtonSpec EtcA[] = {
  { &EtcA1_look, &EtcA1_feel },
  { &EtcA2_look, &EtcA2_feel },
  { &EtcA3_look, &EtcA3_feel },
  { &EtcA4_look, &EtcA4_feel },
  { &EtcA5_look, &EtcA5_feel },
  { &EtcA6_look, &EtcA6_feel },
  { &EtcA7_look, &EtcA7_feel } };
static BoxGeometry EtcA_geo = 
  { 0, 7, 7, 1, 7.000000, 1.000000, 0.000000, 0.000000, 0, 1 };

void MakeEtcPanel ( box, parent, gc, visual, background )
     BoxParent *parent;
     ButtonBox box[1];
     GC gc;
     Visual *visual;
     unsigned long background;
{
  box[0] = MakeButtonBox(&parent[1], gc, visual, background,
			 &EtcA_geo, EtcA, 0);
}
